@@ -34,11 +34,11 @@ class ProducerChannel:
 
 class Producer:
     def __init__(self) -> None:
-        self._host = Setting.get('AMQP', 'HOST')
-        self._heartbeat = Setting.get_bool('AMQP', 'HEARTBEAT')
+        self._host = Setting.AMQP_HOST
+        self._heartbeat = Setting.HEARTBEAT
 
     def send_message(self, destination:str, primitive:str, content:Dict[str, Any]) -> None:
-        destination_queue = Setting.get('QUEUE', destination.upper(), None)
+        destination_queue = Setting.QUEUE.get(destination.upper(), None)
         if destination_queue is None:
             raise Exception('Recipient queue not found in configuration file, please review!')
 
