@@ -11,7 +11,7 @@ class Stub:
     
     def _send(self, primitive:str, content:Dict[str, Any]) -> None:
         self._producer.send_message(
-            destination_queue=self._destination, 
+            destination=self._destination, 
             primitive=primitive, 
             content=content
         )
